@@ -10,5 +10,5 @@ from restless_client.utils import State
 def test_it_set_status_back_to_loadable_if_httperror(request, mcl):
     request.side_effect = requests.HTTPError("Some issue")
     with pytest.raises(requests.HTTPError):
-        apt = mcl.Apartment.get(1)
+        apt = mcl.Apartment.query.get(1)
     assert mcl.state == State.LOADABLE
